@@ -18,7 +18,7 @@ Gibbs_miss<-function(X=X,alpha=alpha,nbit=1,Z=NULL,Zc=NULL,M=NULL,comp_vect=NULL
       Ir=which(Zc!=0)
    }
    if(is.null(sigma_IR)){
-      sigma_IR=rep(0,times=p)#rsidus des regressions (stables pour gibbs)
+      sigma_IR=rep(0,times=p)#residus des regressions (stables pour gibbs)
       for (j in Ir){
          sigma_IR[j]=sd(X[,j]-X%*%alpha[-1,j])
       }
@@ -26,7 +26,7 @@ Gibbs_miss<-function(X=X,alpha=alpha,nbit=1,Z=NULL,Zc=NULL,M=NULL,comp_vect=NULL
    if(is.null(mixmod)){
       mixmod=density_estimation(X = X,detailed = TRUE)
    }
-   missrow=sum(M)#nb d'individus  trou
+   missrow=sum(M)#nb d'individus a trou
    quimiss=which(M!=0,arr.ind = TRUE)
    if(is.null(comp_vect)){
       comp_vect=1+0*M
