@@ -10,7 +10,7 @@ MakeJ<-function(X=X,Z=Z,B=B,Sigma=Sigma,A=A){
    I2=which(colSums(Z)!=0)
    p2=length(I2)
    Z=rbind(0,Z)
-   Z[1,I2]=1#on ajoute une constante  chaque ssreg
+   Z[1,I2]=1#on ajoute une constante a chaque ssreg
    Z=cbind(0,Z)
    I2=I2+1
    pz=sum(Z!=0)
