@@ -2,8 +2,9 @@
 #define _CorReg_kronecker_sum_H
 
 
+
 #include <RcppEigen.h>
 using namespace Rcpp ;
-RcppExport Rcpp::NumericVector kronecker_sum_cpp(const Rcpp::NumericVector &V1,const Rcpp::NumericVector &V2);
+Rcpp::NumericVector kronecker_sum_cpp(const Rcpp::NumericVector &V1,const Rcpp::NumericVector &V2);
 
 #endif
