@@ -4,7 +4,7 @@
 #include <iostream>
 #include <string>
 #include <math.h>
-#include <Rmath.h>
+//#include <Rmath.h>
 
 using namespace Rcpp ;
 using namespace Eigen;
@@ -166,7 +166,7 @@ SEXP rechercheZ_sparse_relax(SEXP X,SEXP Zi,SEXP Zj,SEXP Si,SEXP Sj,SEXP bic_vid
   //liste candidats (couples [i,j])
     if (imet_tirage[0]==0)//methode de changement de la ligne et de la colonne
     {
-      k=int(runif(0,p)[0]);//on tire un numero aleatoire pour savoir quel est la ligne et la colonne de candidats
+      k=int(p*runif(1)[0]);//on tire un numero aleatoire pour savoir quel est la ligne et la colonne de candidats
       for(i=0;i<p;i++)
       {
         if(i!=k)//on ne veut pas avoir de 1 sur la diagonale
@@ -182,7 +182,7 @@ SEXP rechercheZ_sparse_relax(SEXP X,SEXP Zi,SEXP Zj,SEXP Si,SEXP Sj,SEXP bic_vid
     }
     else if (imet_tirage[0]==-1)//seulement la colonne
     {
-      k=int(runif(0,p)[0]);
+      k=int(p*runif(1)[0]);
       for(i=0;i<p;i++)
       {
         if(i!=k)
@@ -197,8 +197,8 @@ SEXP rechercheZ_sparse_relax(SEXP X,SEXP Zi,SEXP Zj,SEXP Si,SEXP Sj,SEXP bic_vid
     {
       for(i=0;i<nbcand;i++)
       {
-        rand1=int(runif(0,p)[0]);//nombres aleatoire pour avoir le numero de la ligne
-        rand2=int(runif(0,p)[0]);//nombres aleatoire pour avoir le numero de la colonne
+        rand1=int(p*runif(1)[0]);//nombres aleatoire pour avoir le numero de la ligne
+        rand2=int(p*runif(1)[0]);//nombres aleatoire pour avoir le numero de la colonne
         if (rand1==rand2)//on ne veut pas de 1 sur la diagonale
         {
           if(rand1<p-1)
